@@ -17,9 +17,7 @@ docs = [
     {
         "answer": "Sentences are passed as a list of string.",
     },
-    {
-        "answer": "The quick brown fox jumps over the lazy dog."
-    },
+    {"answer": "The quick brown fox jumps over the lazy dog."},
 ]
 
 result = twilix.add_objects(collection_name=collection_name, objects=docs)
